==> ynab_split_budget-0.5.0-py3-none-any.whl: ynabsplitbudget/ynabsplitbudget.py <==
from datetime import date, timedelta, datetime
from pathlib import Path
from typing import List, Optional

import yaml

from ynabsplitbudget.client import SplitClient, SyncClient
from ynabsplitbudget.models.exception import BalancesDontMatch
from ynabsplitbudget.models.transaction import RootTransaction, ComplementTransaction
from ynabsplitbudget.syncrepository import SyncRepository
from ynabsplitbudget.userloader import UserLoader


class YnabSplitBudget:
	def __init__(self, path: str, user: str):
		userloader = UserLoader(path=path, user=user)
		self._user = userloader.user
		self._partner = userloader.partner

	def insert_complements(self, since: date = None) -> int:
		since = self._substitute_default_since(since)
		repo = SyncRepository(user=self._user, partner=self._partner)
		transactions = repo.fetch_roots_wo_complement(since=since)

		repo.insert_complements(transactions)
		print(f'inserted {len(transactions)} complements into account of {self._partner.name}')
		return len(transactions)

	def split_transactions(self) -> int:
		c = SplitClient(self._user)
		st_list = c.fetch_new_to_split()
		[c.insert_split(st) for st in st_list]
		print(f'split {len(st_list)} transactions for {self._user.name}')
		return len(st_list)

	def raise_on_balances_off(self):
		repo = SyncRepository(user=self._user, partner=self._partner)
		user_balance, partner_balance = repo.fetch_balances()
		if user_balance + partner_balance != 0:
			raise BalancesDontMatch({'user': {'name': self._user.name,
											  'balance': user_balance},
									 'partner': {'name': self._partner.name,
												 'balance': partner_balance}})

	def delete_orphaned_complements(self, since: date = None) -> List[ComplementTransaction]:
		since = self._substitute_default_since(since)
		orphaned_complements = SyncRepository(user=self._user, partner=self._partner).find_orphaned_partner_complements(since)
		c = SyncClient(self._partner)
		[c.delete_complement(oc.id) for oc in orphaned_complements]
		print(f'deleted {len(orphaned_complements)} orphaned complements in account of {self._partner.name}')
		print(orphaned_complements)
		return orphaned_complements

	@staticmethod
	def _substitute_default_since(since: Optional[date]):
		if since is None:
			return datetime.now() - timedelta(days=30)
		return since

==> ynab_split_budget-0.6.0-py3-none-any.whl: ynabsplitbudget/ynabsplitbudget.py <==
from datetime import date, timedelta, datetime
from typing import List, Optional


from ynabsplitbudget.client import SplitClient, SyncClient
from ynabsplitbudget.fileloader import FileLoader
from ynabsplitbudget.models.exception import BalancesDontMatch
from ynabsplitbudget.models.transaction import ComplementTransaction
from ynabsplitbudget.syncrepository import SyncRepository
from ynabsplitbudget.userloader import UserLoader


class YnabSplitBudget:
	def __init__(self, config: dict, user: str):
		userloader = UserLoader(config_dict=config)
		self._user = userloader.load(user)
		self._partner = userloader.load_partner(user)

	@classmethod
	def from_yaml(cls, path: str, user: str):
		config_dict = FileLoader(path).load()
		return cls(config=config_dict, user=user)

	def insert_complements(self, since: date = None) -> int:
		since = self._substitute_default_since(since)
		repo = SyncRepository(user=self._user, partner=self._partner)
		transactions = repo.fetch_roots_wo_complement(since=since)

		repo.insert_complements(transactions)
		print(f'inserted {len(transactions)} complements into account of {self._partner.name}')
		return len(transactions)

	def split_transactions(self) -> int:
		c = SplitClient(self._user)
		st_list = c.fetch_new_to_split()
		[c.insert_split(st) for st in st_list]
		print(f'split {len(st_list)} transactions for {self._user.name}')
		return len(st_list)

	def raise_on_balances_off(self):
		repo = SyncRepository(user=self._user, partner=self._partner)
		user_balance, partner_balance = repo.fetch_balances()
		if user_balance + partner_balance != 0:
			raise BalancesDontMatch({'user': {'name': self._user.name,
											  'balance': user_balance},
									 'partner': {'name': self._partner.name,
												 'balance': partner_balance}})

	def delete_orphaned_complements(self, since: date = None) -> List[ComplementTransaction]:
		since = self._substitute_default_since(since)
		orphaned_complements = SyncRepository(user=self._user, partner=self._partner).find_orphaned_partner_complements(since)
		c = SyncClient(self._partner)
		[c.delete_complement(oc.id) for oc in orphaned_complements]
		print(f'deleted {len(orphaned_complements)} orphaned complements in account of {self._partner.name}')
		print(orphaned_complements)
		return orphaned_complements

	@staticmethod
	def _substitute_default_since(since: Optional[date]):
		if since is None:
			return datetime.now() - timedelta(days=30)
		return since
